import React from 'react';
import { isLocalStorageNameSupported } from '../utils';
import { Modal } from 'fish';

class Footer extends React.Component {
  componentDidMount() {
    // for some iOS
    // http://stackoverflow.com/a/14555361
    if (!isLocalStorageNameSupported()) {
      return;
    }
    const { pubVersion } = this.props.themeConfig;
    // 大版本发布后全局弹窗提示
    //   1. 点击『知道了』之后不再提示
    //   2. 本地不提示，避免e2e弹出
    if (!location.port && pubVersion && localStorage.getItem(`${pubVersion}-notification-sent`) !== 'true') {
      this.infoNewVersion();
    }
  }
  infoNewVersion = () => {
    const { pubVersion, lastVersion } = this.props.themeConfig;
    Modal.confirm({
      title: <span style={{ paddingLeft: '120px' }}>{`${pubVersion} 发布！🎉 🎉 🎉`}</span>,
      content: (
        <div>
          <img src="//cdncs.101.com/v0.1/static/fish/image/ndlogo.png" alt="fish" />
          <p style={{ paddingLeft: '80px' }}>
            你好，
            <a
              target="_blank"
              rel="noopener noreferrer"
              href="/changelog/"
              onClick={() => {
                localStorage.setItem(`${pubVersion}-notification-sent`, 'true');
              }}
            >
              {pubVersion}
            </a>
            已正式发布，欢迎升级。 如果您还需要使用旧版，请查阅
            <a
              target="_blank"
              rel="noopener noreferrer"
              href={lastVersion.url}
              onClick={() => {
                localStorage.setItem(`${pubVersion}-notification-sent`, 'true');
              }}
            >
              {lastVersion.name}
            </a>
            ，也可通过页面右上角的文档版本选择框进行切换。
          </p>
        </div>
      ),
      okText: '立即升级',
      cancelText: '知道了',
      onOk: () => {
        localStorage.setItem(`${pubVersion}-notification-sent`, 'true');
        window.location.href = '/docs/update';
      },
      onCancel: () => {
        localStorage.setItem(`${pubVersion}-notification-sent`, 'true');
      },
      className: 'new-version-info-modal',
      width: 470,
    });
  };
  render() {
    const { resourceList = [], communityList = [], helpList = [] } = this.props.themeConfig;

    return (
      <div id="footer">
        <ul>
          <li>
            <h2>相关资源</h2>
            {resourceList.map((item, no) => (
              <div key={no}>
                <a target={item.target} href={item.href}>
                  {item.name}
                </a>
              </div>
            ))}
          </li>
          <li>
            <h2>社区</h2>
            {communityList.map((item, no) => (
              <div key={no}>
                <a target={item.target} href={item.href}>
                  {item.name}
                </a>
              </div>
            ))}
          </li>

          <li>
            <h2>帮助</h2>
            {helpList.map((item, no) => (
              <div key={no}>
                <a target={item.target} href={item.href}>
                  {item.name}
                </a>
              </div>
            ))}
          </li>
          <li>
            <h2>Copyright © {new Date().getFullYear()}</h2>
            <div>
              Built with&nbsp;
              <a
                target="_blank"
                rel="noopener noreferrer"
                href="http://git.sdp.nd/component-h5/md-tools"
              >
                md-tools
              </a>
            </div>
          </li>
        </ul>
      </div>
    );
  }
}

export default Footer;
