const path = require('path')
const themeConfig = require(path.join(process.cwd(), 'theme.config.js'))
const pkg = require(path.join(process.cwd(), 'package.json'))
const cname = pkg.name

module.exports = {
  port: 8000,
  root: '/',
  engine: 'md-tools-engine-react',
  source: {
    components: './components',
    docs: './docs',
    changelog: ['CHANGELOG.md'],
    readme: ['README.md']
  },
  theme: 'md-tools-theme-multi-component-react',
  themeConfig: Object.assign(
    {
      projectName: cname,
      homepage: pkg.homepage,
      typeOrder: {
        'Data Entry': 3,
        Other: 7
      },
      resourceList: [
        { href: 'https://gem-mine.club', target: '_blank', name: 'gem-mine' },
        { href: 'http://fish-docs.sdp.101.com', target: '_blank', name: 'fish' },
        { href: 'http://git.sdp.nd/fed/component-boilerplate-multi', target: '_blank', name: '组件库脚手架' }
      ],
      communityList: [
        { href: pkg.homepage, target: '_blank', name: 'GitLab' },
        { href: '/changelog/', target: '_self', name: '更新日志' }
      ],
      helpList: [
        { href: pkg.bugs.url, target: '_blank', name: 'Issues' },
        { href: 'http://ioa.99.com/Load91UMsg.aspx?uin=666595', target: '_blank', name: '@主程' },
        { href: 'http://ioa.99.com/Load91UMsg.aspx?uin=666595', target: '_blank', name: '@开发人员' }
      ]
    },
    themeConfig
  ),
  webpackConfig(config) {
    const alias = {
      'fish/lib': '@sdp.nd/fish/lib',
      fish: '@sdp.nd/fish',
      'react-router': 'react-router/umd/ReactRouter'
    }
    alias[cname + '/lib'] = path.join(process.cwd(), 'components') // 必须alias[cname]上方
    alias[cname] = path.join(process.cwd(), 'components')
    config.resolve.alias = alias
    return config
  }
}
